Authors & Citation
===================================

PyProcar is an open-source project with a community of contributors.
While many of PyProcar's contributors are listed in the :ref:`authors_ref`
section, please be sure to head over to the `Contributors Graph`_.

.. _Contributors Graph: https://github.com/romerogroup/pyprocar/contributors/


.. include:: ../../../CITATION.rst


.. include:: ../../../AUTHORS.rst



License
-------------------------------------

.. include:: ../../../LICENSE